@@ -79,10 +79,10 @@ hyperg_test <- function(term_genes, chosen_genes, background_genes) {
 #' @examples
 #' enrichment(input_genes = c("PER1", "PER2", "CRY1", "CREB1"),
 #'            sig_genes_vec = "PER1",
-#'            background_genes = unlist(kegg_genes))
+#'            background_genes = unlist(pathfindR.data::kegg_genes))
 enrichment <- function(input_genes,
-                       genes_by_term = pathfindR::kegg_genes,
-                       term_descriptions = pathfindR::kegg_descriptions,
+                       genes_by_term = pathfindR.data::kegg_genes,
+                       term_descriptions = pathfindR.data::kegg_descriptions,
                        adj_method = "bonferroni",
                        enrichment_threshold = 5e-2,
                        sig_genes_vec,
@@ -209,8 +209,8 @@ enrichment <- function(input_genes,
 enrichment_analyses <- function(snws,
                                 sig_genes_vec,
                                 pin_name_path = "Biogrid",
-                                genes_by_term = pathfindR::kegg_genes,
-                                term_descriptions = pathfindR::kegg_descriptions,
+                                genes_by_term = pathfindR.data::kegg_genes,
+                                term_descriptions = pathfindR.data::kegg_descriptions,
                                 adj_method = "bonferroni",
                                 enrichment_threshold = 0.05,
                                 list_active_snw_genes = FALSE) {
